Index: src/AST/Pass.impl.hpp
===================================================================
--- src/AST/Pass.impl.hpp	(revision 98e8b3bff3b5c212f4724bd051ba614a77a1be19)
+++ src/AST/Pass.impl.hpp	(revision cebfcb8e306e305227ed83ed9f13328a110bc492)
@@ -154,7 +154,7 @@
 		__pedantic_pass_assert( expr );
 
-		const ast::TypeSubstitution ** env_ptr = __pass::env( core, 0);
-		if ( env_ptr && expr->env ) {
-			*env_ptr = expr->env;
+		const ast::TypeSubstitution ** typeSubs_ptr = __pass::typeSubs( core, 0 );
+		if ( typeSubs_ptr && expr->env ) {
+			*typeSubs_ptr = expr->env;
 		}
 
@@ -177,5 +177,5 @@
 
 		// These may be modified by subnode but most be restored once we exit this statemnet.
-		ValueGuardPtr< const ast::TypeSubstitution * > __old_env         ( __pass::env( core, 0) );
+		ValueGuardPtr< const ast::TypeSubstitution * > __old_env         ( __pass::typeSubs( core, 0 ) );
 		ValueGuardPtr< typename std::remove_pointer< decltype(stmts_before) >::type > __old_decls_before( stmts_before );
 		ValueGuardPtr< typename std::remove_pointer< decltype(stmts_after ) >::type > __old_decls_after ( stmts_after  );
@@ -1488,5 +1488,5 @@
 
 		// These may be modified by subnode but most be restored once we exit this statemnet.
-		ValueGuardPtr< const ast::TypeSubstitution * > __old_env( __pass::env( core, 0) );
+		ValueGuardPtr< const ast::TypeSubstitution * > __old_env( __pass::typeSubs( core, 0 ) );
 		ValueGuardPtr< typename std::remove_pointer< decltype(stmts_before) >::type > __old_decls_before( stmts_before );
 		ValueGuardPtr< typename std::remove_pointer< decltype(stmts_after ) >::type > __old_decls_after ( stmts_after  );
Index: src/AST/Pass.proto.hpp
===================================================================
--- src/AST/Pass.proto.hpp	(revision 98e8b3bff3b5c212f4724bd051ba614a77a1be19)
+++ src/AST/Pass.proto.hpp	(revision cebfcb8e306e305227ed83ed9f13328a110bc492)
@@ -236,5 +236,5 @@
 
 	// List of fields and their expected types
-	FIELD_PTR( env, const ast::TypeSubstitution * )
+	FIELD_PTR( typeSubs, const ast::TypeSubstitution * )
 	FIELD_PTR( stmtsToAddBefore, std::list< ast::ptr< ast::Stmt > > )
 	FIELD_PTR( stmtsToAddAfter , std::list< ast::ptr< ast::Stmt > > )

Index: src/AST/Pass.hpp
===================================================================
--- src/AST/Pass.hpp	(revision 98e8b3bff3b5c212f4724bd051ba614a77a1be19)
+++ src/AST/Pass.hpp	(revision cebfcb8e306e305227ed83ed9f13328a110bc492)
@@ -50,5 +50,5 @@
 // | PureVisitor           - makes the visitor pure, it never modifies nodes in place and always
 //                           clones nodes it needs to make changes to
 // | WithTypeSubstitution  - provides polymorphic const TypeSubstitution * env for the
 //                           current expression
 // | WithStmtsToAdd        - provides the ability to insert statements before or after the current
@@ -294,11 +294,10 @@
 //-------------------------------------------------------------------------------------------------
 
-/// Keep track of the polymorphic const TypeSubstitution * env for the current expression
-
 /// If used the visitor will always clone nodes.
 struct PureVisitor {};
 
+/// Keep track of the polymorphic const TypeSubstitution * typeSubs for the current expression.
 struct WithConstTypeSubstitution {
-	const TypeSubstitution * env = nullptr;
+	const TypeSubstitution * typeSubs = nullptr;
 };
 
@@ -50,5 +50,5 @@
 // | PureVisitor           - makes the visitor pure, it never modifies nodes in place and always
 //                           clones nodes it needs to make changes to
-// | WithTypeSubstitution  - provides polymorphic const TypeSubstitution * env for the
+// | WithConstTypeSubstitution - provides polymorphic const TypeSubstitution * typeSubs for the
 //                           current expression
 // | WithStmtsToAdd        - provides the ability to insert statements before or after the current